@@ -5,11 +5,11 @@
 # likelihood
 IRT.likelihood.immer_HRM <- function( object , ... ){
     ll <- object$f.yi.qk
-    attr(ll,"theta") <- object$theta_like
-	attr(ll,"prob.theta") <- object$pi.k
-	attr(ll,"G") <- 1
-    return(ll)
-        }
+    base::attr(ll,"theta") <- object$theta_like
+	base::attr(ll,"prob.theta") <- object$pi.k
+	base::attr(ll,"G") <- 1
+    base::return(ll)
+}
 #############################################################		
 
 
@@ -17,9 +17,9 @@ IRT.likelihood.immer_HRM <- function( object , ... ){
 # posterior
 IRT.posterior.immer_HRM <- function( object , ... ){
     ll <- object$f.qk.yi
-    attr(ll,"theta") <- object$theta_like
-	attr(ll,"prob.theta") <- object$pi.k
-	attr(ll,"G") <- 1
-    return(ll)
-        }
+    base::attr(ll,"theta") <- object$theta_like
+	base::attr(ll,"prob.theta") <- object$pi.k
+	base::attr(ll,"G") <- 1
+    base::return(ll)
+}
 #############################################################	
\ No newline at end of file
