@@ -4,16 +4,16 @@
 MHprop_hrm <- function( MHprop , b , a , phi , theta , iter , burnin ){
 
 	psi <- phi
-	MHprop <- list()
+	MHprop <- base::list()
 	
 	# logical indicating whether standard deviation of the
 	# proposal distribution is calculated according to
 	# Browne and Draper (2006)
 	MHprop$refresh_formula <- TRUE
 	
-	MHprop$SD <- list( "b" = .4+0*b , "a" = .4 +0*a , "phi" = .2 + 0*phi , "psi" = .4 + 0*psi ,
+	MHprop$SD <- base::list( "b" = .4+0*b , "a" = .4 +0*a , "phi" = .2 + 0*phi , "psi" = .4 + 0*psi ,
 			"theta" = .5 + 0*theta ) 
-	MHprop$accept <- list("b" = 0 + 0*b , "a" = 0 + 0*a , "phi" = 0+0*phi ,
+	MHprop$accept <- base::list("b" = 0 + 0*b , "a" = 0 + 0*a , "phi" = 0+0*phi ,
 						"psi" = 0 + 0*psi , "theta" = 0 + 0*theta  )
 
 	MHprop$refresh_count$b <- 0
@@ -39,25 +39,24 @@ MHprop_hrm <- function( MHprop , b , a , phi , theta , iter , burnin ){
 	vars <- c("b" ,"a" , "phi" , "psi" , "theta") 
 	
 	# compute iterations for which MH updatings must be computed
-	refresh_iters <- sort( unique( unlist( MHprop$refresh_iter ) ) )
-	RI <- length(refresh_iters)
+	refresh_iters <- base::sort( base::unique( base::unlist( MHprop$refresh_iter ) ) )
+	RI <- base::length(refresh_iters)
 	v1 <- NULL
 	for (rr in 1:RI){
 		 l1 <- ( 1:iter %% refresh_iters[rr] ) == 0 
 		 l1 <- (1:iter)[l1]
-	     v1 <- c( v1 , l1 ) 
-					}
-	v2 <- sort( unique(v1) )
+	     v1 <- base::c( v1 , l1 ) 
+	}
+	v2 <- base::sort( base::unique(v1) )
 	v2 <- v2[ v2 <= burnin ]
 	MHprop$ITER_refreshing <- v2
 	
-	
 	# refreshing variables
-	MHprop$VARS_refreshing <- c("b" , "phi" , "psi" , "theta") 
+	MHprop$VARS_refreshing <- base::c("b" , "phi" , "psi" , "theta") 
 	
 	# boundaries for acceptance rates
-	MHprop$accept_bounds <- c( .4 , .6 )
+	MHprop$accept_bounds <- base::c( .4 , .6 )
 	
-	return(MHprop)
-	}
+	base::return(MHprop)
+}
 ######################################################################	
\ No newline at end of file
