@@ -10,6 +10,6 @@ immer_mcmc_draw_variance <- function( N , w0 , sig02 , n , sig2 ){
     # n ... empirical sample size
     # sig2 ... empirical variance
     res <- 1/ stats::rgamma( N , (w0+n) / 2 , 0.5 * ( w0*sig02 + n*sig2 ) )
-    return(res) 
-        }
+    base::return(res) 
+ }
 #####################################################################
\ No newline at end of file
