@@ -6,15 +6,15 @@
 .onAttach <- function(libname,pkgname){
   d <- utils::packageDescription("immer")
   d1 <- d$Version
-  packageStartupMessage(
-		paste("" ,d$Package," " , d1 ," (",d$Date,")",sep="")  )
+  base::packageStartupMessage(
+		base::paste("* " ,d$Package," " , d1 ," (",d$Date,")",sep="")  )
 	}
 	
 	
 version <- function(pkg="immer"){
-  lib <- dirname(system.file(package = pkg))
+  lib <- base::dirname(system.file(package = pkg))
   d <- utils::packageDescription(pkg)
-  return(paste(d$Package,d$Version,d$Date,lib))
+  base::return( base::paste(d$Package,d$Version,d$Date,lib) )
 }
 
 # .First.lib <- function(lib, pkg){
